@@ -42,28 +42,23 @@ BASE_PROMPT = """You have an instance `env` with methods:
 - `env.get_text_from_page(entire_page)` returns the free text from the page. If entire_page is True, it returns all the text from HTML doc. If False, returns only visible text.
 
 Guidelines for using GPTWebElement:
-1. `element.text` returns the text of the element.
-2. `element.get_attribute(attr)` returns the value of the attribute of the element. If the attribute does not exist, it returns ''.
-3. `element.find_elements(by='id', value=None)` is similar to `env.find_elements()` except that it only searches the children of the element and does not search iframes.
-4. `env.is_element_visible_in_viewport(element)` returns if the element is visible in the viewport.
-5. Do NOT use `element.send_keys(text)` or `element.click()`. Use `env.send_keys(text)` and `env.click(element)` instead.
-
-In xpaths, to get the text of an element, do NOT use `text()`. Use `normalize-space()` instead.
-The xpath for an element whose text is "text" is "//*[normalize-space() = 'text']". The xpath for an element that contains text is "//*[contains(normalize-space(), 'text')]".
-The xpath of a text box is usually "//input|//div[@role = 'textarea']|//div[@role = 'textbox']".
-The xpath for a button is usually "//button|//div[@role = 'button']", but it may sometimes also be an anchor.
+- `element.get_attribute(attr)` returns the value of the attribute of the element. If the attribute does not exist, it returns ''.
+- `element.find_elements(by='id', value=None)` is similar to `env.find_elements()` except that it only searches the children of the element and does not search iframes.
+- `env.is_element_visible_in_viewport(element)` returns if the element is visible in the viewport.
 
 INSTRUCTIONS:
 {instructions}
 
 Your code must obey the following constraints:
+- In xpaths, to get the text of an element, do NOT use `text()`. Use `normalize-space()` instead. The xpath for an element whose text is "text" is "//*[normalize-space() = 'text']". The xpath for an element that contains text is "//*[contains(normalize-space(), 'text')]".
+- Do NOT use `element.text` to get text. Use `env.get_text_of_element(element)` instead.
+- Do NOT use `element.send_keys(text)` or `element.click()`. Use `env.send_keys(text)` and `env.click(element)` instead.
 - Only do what I instruct you to do.
 - Only write code, no comments.
 - Has correct indentation.
 - Respect case sensitivity in the instructions.
 - Does not call any functions besides those given above and those defined by the base language spec.
 - You may not import any modules. You may not use any external libraries.
-- Always start with `env.get(url)` to go to a URL. If none is given, go to https://google.com.
 
 OUTPUT: ```python"""
 
@@ -109,7 +104,7 @@ class InstructionCompiler:
             isinstance(instructions, str)
             or isinstance(instructions, io.TextIOWrapper)
             or isinstance(instructions, dict)
-        )
+        ), f"Instructions must be of type str or file buffer, not {type(instructions)}."
 
         # Instance variables.
         self.model = model
